@@ -1,23 +1,32 @@
 import logging
-import os
 import random
 import socket
 import string
 import time
+from typing import TYPE_CHECKING
 
 import pytest
 
+if TYPE_CHECKING:
+    from docker.models.containers import Container
+
 logger = logging.getLogger(__name__)
 
 
 def wait_until(pred, timeout: float, pause: float = 0.1):
     start = time.perf_counter()
+    exc = None
     while (time.perf_counter() - start) < timeout:
-        value = pred()
-        if value:
-            return value
+        try:
+            value = pred()
+        except Exception as e:  # pylint: disable=broad-except
+            exc = e
+        else:
+            if value:
+                return value
         time.sleep(pause)
-    raise TimeoutError("timed out waiting")
+
+    raise TimeoutError("timed out waiting") from exc
 
 
 def random_string(n: int = 6):
@@ -46,9 +55,14 @@ def docker_client():
     client.close()
 
 
-def is_pytest_session() -> bool:
-    """returns true if currently running a pytest session"""
-    return "PYTEST_CURRENT_TEST" in os.environ
+def wait_until_running(
+    container: "Container", timeout: int = 30, pause: float = 0.5
+):
+    def check():
+        container.reload()
+        return container.status == "running"
+
+    wait_until(check, timeout=timeout, pause=pause)
 
 
 def get_free_port() -> None:
